# This script downloads all the available raw data used. It must be
# run in an environment with an internet connection i.e. not on a worker node.

suppressMessages({
  library(TENxPBMCData)
  library(scRNAseq)
  library(AnnotationHub)
  library(zellkonverter)
  library(tibble)
  library(EnsDb.Mmusculus.v79)
})

raw_lawlor <- LawlorPancreasData()
saveRDS(raw_lawlor, here::here("data", "raw_data", "lawlor.rds"))

raw_pbmc3k <- TENxPBMCData(dataset = "pbmc3k")
saveRDS(raw_pbmc3k, here::here("data", "raw_data", "pbmc3k.rds"))

raw_zeisel <- ZeiselBrainData()
saveRDS(raw_zeisel, here::here("data", "raw_data", "zeisel.rds"))

raw_zhao <- ZhaoImmuneLiverData()
saveRDS(raw_zhao, here::here("data", "raw_data", "zhao.rds"))

edb <- AnnotationHub()[["AH73881"]]
saveDb(edb, here::here("data", "edb.sqlite"))

# We assume (perhaps slightly oddly given the name of this file) that the raw
# .h5ad  file has already been downloaded.)
# FIXME: Download the data as part of this file.

# Here we just take the all_cell data, which contains the raw count matrix
# and then subset it to only astrocytes and add the cell-type annotation using
# the information in the provided .csv file. We then process the raw counts
# ourselves in the `prep-astrocyte.R` file.

# TODO: We could also download the normalised and gene filtered data for
# cellxgene (NB: This does not contain raw counts.) and merge it into the other
# data. When I tried this however I was stymied by the lack of gene symbols
# in the all cells data...

c2l_all_cells_sce <- readH5AD(here::here(
  "data",
  "downloaded_data",
  "all_cells_20200625.h5ad"
))

# c2l_astrocytes_sce <- readH5AD(here::here(
#   "data",
#   "downloaded_data",
#   "mouse_brain_snRNA_with_UMAP_astrocytes_cellxgene.h5ad"
# ))

c2l_cell_labels <- tibble(read.csv(here::here(
  "data",
  "downloaded_data",
  "snRNA_annotation_astro_subtypes_refined59_20200823.csv"
)))

colnames(c2l_cell_labels) <- c("cell_label", "annotation")
c2l_cell_labels$is_astro <- substr(c2l_cell_labels$annotation, 1, 5) == "Astro"

astro_cell_labels <- c2l_cell_labels$cell_label[c2l_cell_labels$is_astro]
astro_annotations <- c2l_cell_labels$annotation[c2l_cell_labels$is_astro]

astro_sce <- c2l_all_cells_sce[, astro_cell_labels]

colLabels(astro_sce) <- astro_annotations

saveRDS(astro_sce, here::here("data", "raw_data", "astrocyte.rds"))
